summaryrefslogtreecommitdiff
path: root/src/lib/film.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/film.h')
-rw-r--r--src/lib/film.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/film.h b/src/lib/film.h
index 648d9828b..f095023a3 100644
--- a/src/lib/film.h
+++ b/src/lib/film.h
@@ -177,10 +177,10 @@ public:
return _audio_language;
}
/** @param burnt_in If non-null, filled with true if all subtitles are burnt in, otherwise false.
* @return pair containing the main subtitle language, and additional languages
*/
- std::pair<boost::optional<dcp::LanguageTag>, std::vector<dcp::LanguageTag>> subtitle_languages(bool* burnt_in = nullptr) const;
+ std::pair<boost::optional<dcp::LanguageTag>, std::vector<dcp::LanguageTag>> open_text_languages(bool* burnt_in = nullptr) const;
/** @return all closed caption languages in the film */
std::vector<dcp::LanguageTag> closed_caption_languages() const;
@@ -177,10 +177,10 @@ public:
return _audio_language;
}
- /** @param burnt_in If non-null, filled with true if all subtitles are burnt in, otherwise false.
- * @return pair containing the main subtitle language, and additional languages
+ /** @param burnt_in If non-null, filled with true if all open subtitles/captions are burnt in, otherwise false.
+ * @return pair containing the main open subtitle/caption language, and additional languages
*/